==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_entities/equiplinearref_001/OffsetandSizeDetails.java <==

package net.datastream.schemas.mp_entities.equiplinearref_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.TYPE_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATIONSHIPTYPEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HORIZONTALOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HORIZONTALOFFSETUOMCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HORIZONTALOFFSETTYPEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VERTICALOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VERTICALOFFSETUOMCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VERTICALOFFSETTYPEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QTYPERUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QTYUOMCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WIDTH" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WIDTHUOMCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HEIGHT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HEIGHTUOMCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "relationshiptypeid",
    "horizontaloffset",
    "horizontaloffsetuomcode",
    "horizontaloffsettypeid",
    "verticaloffset",
    "verticaloffsetuomcode",
    "verticaloffsettypeid",
    "qtyperuom",
    "qtyuomcode",
    "width",
    "widthuomcode",
    "height",
    "heightuomcode"
})
@XmlRootElement(name = "OffsetandSizeDetails")
public class OffsetandSizeDetails {

    @XmlElement(name = "RELATIONSHIPTYPEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type relationshiptypeid;
    @XmlElement(name = "HORIZONTALOFFSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY horizontaloffset;
    @XmlElement(name = "HORIZONTALOFFSETUOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String horizontaloffsetuomcode;
    @XmlElement(name = "HORIZONTALOFFSETTYPEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type horizontaloffsettypeid;
    @XmlElement(name = "VERTICALOFFSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY verticaloffset;
    @XmlElement(name = "VERTICALOFFSETUOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String verticaloffsetuomcode;
    @XmlElement(name = "VERTICALOFFSETTYPEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type verticaloffsettypeid;
    @XmlElement(name = "QTYPERUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY qtyperuom;
    @XmlElement(name = "QTYUOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String qtyuomcode;
    @XmlElement(name = "WIDTH", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY width;
    @XmlElement(name = "WIDTHUOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String widthuomcode;
    @XmlElement(name = "HEIGHT", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY height;
    @XmlElement(name = "HEIGHTUOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String heightuomcode;

    /**
     * Obtient la valeur de la propriété relationshiptypeid.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getRELATIONSHIPTYPEID() {
        return relationshiptypeid;
    }

    /**
     * Définit la valeur de la propriété relationshiptypeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setRELATIONSHIPTYPEID(TYPE_Type value) {
        this.relationshiptypeid = value;
    }

    /**
     * Obtient la valeur de la propriété horizontaloffset.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getHORIZONTALOFFSET() {
        return horizontaloffset;
    }

    /**
     * Définit la valeur de la propriété horizontaloffset.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setHORIZONTALOFFSET(QUANTITY value) {
        this.horizontaloffset = value;
    }

    /**
     * Obtient la valeur de la propriété horizontaloffsetuomcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHORIZONTALOFFSETUOMCODE() {
        return horizontaloffsetuomcode;
    }

    /**
     * Définit la valeur de la propriété horizontaloffsetuomcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHORIZONTALOFFSETUOMCODE(String value) {
        this.horizontaloffsetuomcode = value;
    }

    /**
     * Obtient la valeur de la propriété horizontaloffsettypeid.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getHORIZONTALOFFSETTYPEID() {
        return horizontaloffsettypeid;
    }

    /**
     * Définit la valeur de la propriété horizontaloffsettypeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setHORIZONTALOFFSETTYPEID(TYPE_Type value) {
        this.horizontaloffsettypeid = value;
    }

    /**
     * Obtient la valeur de la propriété verticaloffset.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getVERTICALOFFSET() {
        return verticaloffset;
    }

    /**
     * Définit la valeur de la propriété verticaloffset.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setVERTICALOFFSET(QUANTITY value) {
        this.verticaloffset = value;
    }

    /**
     * Obtient la valeur de la propriété verticaloffsetuomcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVERTICALOFFSETUOMCODE() {
        return verticaloffsetuomcode;
    }

    /**
     * Définit la valeur de la propriété verticaloffsetuomcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVERTICALOFFSETUOMCODE(String value) {
        this.verticaloffsetuomcode = value;
    }

    /**
     * Obtient la valeur de la propriété verticaloffsettypeid.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getVERTICALOFFSETTYPEID() {
        return verticaloffsettypeid;
    }

    /**
     * Définit la valeur de la propriété verticaloffsettypeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setVERTICALOFFSETTYPEID(TYPE_Type value) {
        this.verticaloffsettypeid = value;
    }

    /**
     * Obtient la valeur de la propriété qtyperuom.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getQTYPERUOM() {
        return qtyperuom;
    }

    /**
     * Définit la valeur de la propriété qtyperuom.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setQTYPERUOM(QUANTITY value) {
        this.qtyperuom = value;
    }

    /**
     * Obtient la valeur de la propriété qtyuomcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getQTYUOMCODE() {
        return qtyuomcode;
    }

    /**
     * Définit la valeur de la propriété qtyuomcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setQTYUOMCODE(String value) {
        this.qtyuomcode = value;
    }

    /**
     * Obtient la valeur de la propriété width.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getWIDTH() {
        return width;
    }

    /**
     * Définit la valeur de la propriété width.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setWIDTH(QUANTITY value) {
        this.width = value;
    }

    /**
     * Obtient la valeur de la propriété widthuomcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWIDTHUOMCODE() {
        return widthuomcode;
    }

    /**
     * Définit la valeur de la propriété widthuomcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWIDTHUOMCODE(String value) {
        this.widthuomcode = value;
    }

    /**
     * Obtient la valeur de la propriété height.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getHEIGHT() {
        return height;
    }

    /**
     * Définit la valeur de la propriété height.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setHEIGHT(QUANTITY value) {
        this.height = value;
    }

    /**
     * Obtient la valeur de la propriété heightuomcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHEIGHTUOMCODE() {
        return heightuomcode;
    }

    /**
     * Définit la valeur de la propriété heightuomcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHEIGHTUOMCODE(String value) {
        this.heightuomcode = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/equiplinearref_001/OffsetandSizeDetails.java <==

package net.datastream.schemas.mp_entities.equiplinearref_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.TYPE_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RELATIONSHIPTYPEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}HORIZONTALOFFSET" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}HORIZONTALOFFSETUOMCODE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}HORIZONTALOFFSETTYPEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}VERTICALOFFSET" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}VERTICALOFFSETUOMCODE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}VERTICALOFFSETTYPEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}QTYPERUOM" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}QTYUOMCODE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WIDTH" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WIDTHUOMCODE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}HEIGHT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}HEIGHTUOMCODE" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "relationshiptypeid",
    "horizontaloffset",
    "horizontaloffsetuomcode",
    "horizontaloffsettypeid",
    "verticaloffset",
    "verticaloffsetuomcode",
    "verticaloffsettypeid",
    "qtyperuom",
    "qtyuomcode",
    "width",
    "widthuomcode",
    "height",
    "heightuomcode"
})
@XmlRootElement(name = "OffsetandSizeDetails")
public class OffsetandSizeDetails {

    @XmlElement(name = "RELATIONSHIPTYPEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type relationshiptypeid;
    @XmlElement(name = "HORIZONTALOFFSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY horizontaloffset;
    @XmlElement(name = "HORIZONTALOFFSETUOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String horizontaloffsetuomcode;
    @XmlElement(name = "HORIZONTALOFFSETTYPEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type horizontaloffsettypeid;
    @XmlElement(name = "VERTICALOFFSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY verticaloffset;
    @XmlElement(name = "VERTICALOFFSETUOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String verticaloffsetuomcode;
    @XmlElement(name = "VERTICALOFFSETTYPEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type verticaloffsettypeid;
    @XmlElement(name = "QTYPERUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY qtyperuom;
    @XmlElement(name = "QTYUOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String qtyuomcode;
    @XmlElement(name = "WIDTH", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY width;
    @XmlElement(name = "WIDTHUOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String widthuomcode;
    @XmlElement(name = "HEIGHT", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY height;
    @XmlElement(name = "HEIGHTUOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String heightuomcode;

    /**
     * Gets the value of the relationshiptypeid property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getRELATIONSHIPTYPEID() {
        return relationshiptypeid;
    }

    /**
     * Sets the value of the relationshiptypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setRELATIONSHIPTYPEID(TYPE_Type value) {
        this.relationshiptypeid = value;
    }

    /**
     * Gets the value of the horizontaloffset property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getHORIZONTALOFFSET() {
        return horizontaloffset;
    }

    /**
     * Sets the value of the horizontaloffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setHORIZONTALOFFSET(QUANTITY value) {
        this.horizontaloffset = value;
    }

    /**
     * Gets the value of the horizontaloffsetuomcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHORIZONTALOFFSETUOMCODE() {
        return horizontaloffsetuomcode;
    }

    /**
     * Sets the value of the horizontaloffsetuomcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHORIZONTALOFFSETUOMCODE(String value) {
        this.horizontaloffsetuomcode = value;
    }

    /**
     * Gets the value of the horizontaloffsettypeid property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getHORIZONTALOFFSETTYPEID() {
        return horizontaloffsettypeid;
    }

    /**
     * Sets the value of the horizontaloffsettypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setHORIZONTALOFFSETTYPEID(TYPE_Type value) {
        this.horizontaloffsettypeid = value;
    }

    /**
     * Gets the value of the verticaloffset property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getVERTICALOFFSET() {
        return verticaloffset;
    }

    /**
     * Sets the value of the verticaloffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setVERTICALOFFSET(QUANTITY value) {
        this.verticaloffset = value;
    }

    /**
     * Gets the value of the verticaloffsetuomcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVERTICALOFFSETUOMCODE() {
        return verticaloffsetuomcode;
    }

    /**
     * Sets the value of the verticaloffsetuomcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVERTICALOFFSETUOMCODE(String value) {
        this.verticaloffsetuomcode = value;
    }

    /**
     * Gets the value of the verticaloffsettypeid property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getVERTICALOFFSETTYPEID() {
        return verticaloffsettypeid;
    }

    /**
     * Sets the value of the verticaloffsettypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setVERTICALOFFSETTYPEID(TYPE_Type value) {
        this.verticaloffsettypeid = value;
    }

    /**
     * Gets the value of the qtyperuom property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getQTYPERUOM() {
        return qtyperuom;
    }

    /**
     * Sets the value of the qtyperuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setQTYPERUOM(QUANTITY value) {
        this.qtyperuom = value;
    }

    /**
     * Gets the value of the qtyuomcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getQTYUOMCODE() {
        return qtyuomcode;
    }

    /**
     * Sets the value of the qtyuomcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setQTYUOMCODE(String value) {
        this.qtyuomcode = value;
    }

    /**
     * Gets the value of the width property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getWIDTH() {
        return width;
    }

    /**
     * Sets the value of the width property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setWIDTH(QUANTITY value) {
        this.width = value;
    }

    /**
     * Gets the value of the widthuomcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWIDTHUOMCODE() {
        return widthuomcode;
    }

    /**
     * Sets the value of the widthuomcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWIDTHUOMCODE(String value) {
        this.widthuomcode = value;
    }

    /**
     * Gets the value of the height property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getHEIGHT() {
        return height;
    }

    /**
     * Sets the value of the height property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setHEIGHT(QUANTITY value) {
        this.height = value;
    }

    /**
     * Gets the value of the heightuomcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHEIGHTUOMCODE() {
        return heightuomcode;
    }

    /**
     * Sets the value of the heightuomcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHEIGHTUOMCODE(String value) {
        this.heightuomcode = value;
    }

}
